@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2025 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -69,6 +69,10 @@ struct ref;
 	_(MAIN_TAG,		""), \
 	_(MAIN_LOCAL_TAG,	""), \
 	_(MAIN_REMOTE,		""), \
+	_(MAIN_STASH,		""), \
+	_(MAIN_NOTE,		""), \
+	_(MAIN_PREFETCH,	""), \
+	_(MAIN_OTHER,		""), \
 	_(MAIN_REPLACE,		""), \
 	_(MAIN_TRACKED,		""), \
 	_(MAIN_REF,		""), \
