@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2025 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -460,7 +460,7 @@ readline_init(void)
 	/* Allow conditional parsing of the ~/.inputrc file. */
 	rl_readline_name = "tig";
 
-	/* Word break caracters (we removed '(' to match variables) */
+	/* Word break characters (we removed '(' to match variables) */
 	rl_basic_word_break_characters = " \t\n\"\\'`@$><=;|&{";
 
 	/* Custom display function */
@@ -499,6 +499,7 @@ read_prompt(const char *prompt)
 	curs_set(1);
 	if (signal(SIGINT, sigint_absorb_handler) == SIG_ERR)
 		die("Failed to setup sigint handler");
+	noraw();
 	cbreak();
 	line = readline(prompt);
 	raw();
@@ -872,8 +873,14 @@ prompt_toggle(struct view *view, const char *argv[], enum view_flag *flags)
 	}
 
 	toggle = find_option_info(option_toggles, ARRAY_SIZE(option_toggles), "", option);
-	if (toggle)
+	if (toggle) {
+		if ((view_has_flags(view, VIEW_FILE_FILTER) &&
+		     !strcmp(toggle->name, "file_filter")) ||
+		    (view_has_flags(view, VIEW_REV_FILTER) &&
+		     !strcmp(toggle->name, "rev_filter")))
+			string_copy_rev(view->env->goto_id, view->env->commit);
 		return prompt_toggle_option(view, argv, "", toggle, flags);
+	}
 
 	for (column = view->columns; column; column = column->next) {
 		toggle = find_column_option_info(column->type, &column->opt, option, &template, &column_name);
