@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2025 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -135,6 +135,8 @@ static bool
 tree_read_date(struct view *view, struct buffer *buf, struct tree_state *state)
 {
 	char *text = buf ? buf->data : NULL;
+	struct view_column *column = get_view_column(view, VIEW_COLUMN_DATE);
+	bool use_author_date = column && column->opt.date.use_author;
 
 	if (!text && state->read_date) {
 		state->read_date = false;
@@ -167,7 +169,11 @@ tree_read_date(struct view *view, struct buffer *buf, struct tree_state *state)
 
 	} else if (*text == 'a' && get_line_type(text) == LINE_AUTHOR) {
 		parse_author_line(text + STRING_SIZE("author "),
-				  &state->author, &state->author_time);
+				  &state->author, use_author_date ? &state->author_time : NULL);
+
+	} else if (*text == 'c' && get_line_type(text) == LINE_COMMITTER) {
+		parse_author_line(text + STRING_SIZE("committer "),
+				  NULL, use_author_date ? NULL : &state->author_time);
 
 	} else if (*text == ':') {
 		char *pos;
@@ -482,7 +488,7 @@ tree_open(struct view *view, enum open_flags flags)
 static struct view_ops tree_ops = {
 	"file",
 	argv_env.commit,
-	VIEW_SEND_CHILD_ENTER | VIEW_SORTABLE,
+	VIEW_SEND_CHILD_ENTER | VIEW_SORTABLE | VIEW_BLAME_LIKE | VIEW_REFRESH,
 	sizeof(struct tree_state),
 	tree_open,
 	tree_read,
